# Build a circuit on the breadboard
# read a button and control an LED
# CC0 code from www.tinkerfarm.net

# Review breadboards and Pico pinout chart
# Build the circuit:
#  Jumper physical pin 3 (GND) to left breadboard blue GND rail.
#  Jumper physical pin 36 (3V3) to left breadboard red Power rail.
#  Place a LED across the trench in the breadboard
#   with the positive (long) leg of the LED on the left side.
#  Insert a 330 ohm (brown) resistor from GP13 (physical pin 17) to
#   the positive row of the LED.
#  Jumper negative row of the LED to ground rail.
#  Insert a button across the trench.
#  Jumper power rail to left button row.
#  Jumper the other (diagonal) button row on the right side to GP9 (physical pin 12)

# import modules
import machine
import utime

# create objects for LED output and button input
# we used an external resistor to protect the output to the LED
led_external = machine.Pin(13, machine.Pin.OUT)
# we are turning on the internal resistor to protect input from the button
button = machine.Pin(9, machine.Pin.IN, machine.Pin.PULL_DOWN)

# loop forever
while True:
    # if the button is pressed turn on the led for 2 seconds
    if button.value() == 1:
        led_external.value(1)
        utime.sleep(2)
    # otherwise turn the led off
    led_external.value(0)


