# Use an interrupt to detect motion from a PIR sensor
# CC0 code from www.tinkerfarm.net

# circuit:
# Jumper physical pin 36 (3V3) to power rail
# Jumper physical pin 3 (ground) to GND rail
# Jumper Power rail to PIR VCC (red dot)
# Jumper Ground rail to PIR GND (black dot)
# Jumper pico GP2 (physical pin 4) to PIR output (middle pin)

# import the modules we will use
import machine
import utime

# create an object to read GP2 as input with pull down resistor
sensor_pir = machine.Pin(2, machine.Pin.IN, machine.Pin.PULL_DOWN)
# create a variable to output to LED built in on GP25
led = machine.Pin(25, machine.Pin.OUT)

# create an interrupt service routine (ISR) to act on an interrupt
# we will call it next
def pir_handler(pin):
    # print to the monitor
    print("ALARM! Motion detected!")
    # flash the LED 50 times
    # the PIR needs about 5 seconds to reset anyway
    for i in range(50):
        # toggle led on or off
        led.toggle()
        # pause 100 milliseconds
        utime.sleep_ms(100)

# call the ISR above when a rising value is received on the PIR input pin
# we have already assigned sensor_pir to the pin
# we have already defined the routine to handle the interrupt
sensor_pir.irq(trigger=machine.Pin.IRQ_RISING, handler=pir_handler)
