# use an analog potentiometer to control LED
# use pwm to make the LED appear to ramp in brightness
# open View | Plotter to graph the output of the pot
# CC0 code from www.tinkerfarm.net

# circuit:
# Jumper pin 36 (3V3) to power rail
# Jumper pin 3 (GND) to ground rail
# Insert pot across 3 rows on left side of breadboard
# Jumper power rail to outside pin on pot
# Jumper ground rail to the other outside pin on pot
# Jumper GP28 aka ADC2 (physical pin 34) to middle pin on pot

# import modules
import machine
import utime

# assign ADC2 pin to object using the analog to digital circuit
potentiometer = machine.ADC(2)
# assign the internal LED for pulse width modulation (PWM)
led = machine.PWM(machine.Pin(25))

# set the PWM frequency of the LED -- how often it updates
# we will be flickering it really fast so our eyes see it
# as brighter or dimmer rather than as flickering
led.freq(1000)

# run forever
while True:
    # read the pot position as a 16 bit unsigned integer
    potValue = potentiometer.read_u16()
    # set the on time of the led to the pot value
    # duty is what percentage of each frequency cycle it is on
    # duty is also a 16 bit unsigned integer
    led.duty_u16(potValue)
    # print the pot value for graphing
    print(potValue)
    # a brief pause gives a more stable display
    utime.sleep(0.1)