# example of I2C & display with external python module
# CC0 code from www.tinkerfarm.net

# circuit:
# Insert ssd1306 display module into 4 breadboard rows
# Jumper 3.3v power rail to display VCC
# Jumper ground rail to display GND
# Jumper GP2 (Pico I2C1 SDA, physical pin 4) to display SDA
# Jumper GP3 (Pico I2C1 SCL, physical pin 5) to display SCL

# import modules
from machine import Pin, I2C
import math
import utime

# for this module we are just loading a python program from the files
# this file has to be in the root directory
# it is the code for the hardware that controls the display
from ssd1306 import SSD1306_I2C

# assign pins to I2C SDA (serial data) and SCL (serial clock)
sda_pin=machine.Pin(2)
scl_pin=machine.Pin(3)

# create I2C object and set the I2C channel, pins, frequency
i2c=machine.I2C(1, sda=sda_pin, scl=scl_pin, freq=400000)

# create oled object setting the screen Width, Height and assigning it to I2C
# this uses the display hardware module
oled = SSD1306_I2C(128, 32, i2c)

# create a variable for the built in thermometer
sensor_temp = machine.ADC(4)

# print a scan of the I2C address to make sure we are connected to the display
print(i2c.scan())

# loop to keep updating temp display
while True:
    
    # take a reading (as 16 bit unsigned integer) of the temp and convert to voltage
    reading = sensor_temp.read_u16() * 0.00005
    # convert reading to temperature and round to 1 decimal
    temperature = round(27 - (reading -0.706)/0.001721, 1)
    
    # fill display with black
    oled.fill(0)
    # dislpay text with column, row starting points
    oled.text("Raspberry Pi",5,5)
    oled.text("Pico",5,15)
    oled.text("Temp:",5,25)
    # temperature needs to be converted to a string (text) first
    # then it can be displayed
    oled.text(str(temperature),45, 25)
    # update display
    oled.show()
    # brief delay to stop flickering
    utime.sleep(.5)

